@@ -120,10 +120,12 @@
 #' set.seed(150520)
 #' data(enzyme)
 #' x <- enzyme
-#' Enzyme1.out <- MixNRMI1(x, Alpha = 1, Kappa = 0.007, Gama = 0.5,
-#'                          distr.k = "gamma", distr.p0 = "gamma",
-#'                          asigma = 1, bsigma = 1, Meps=0.005,
-#'                          Nit = 5000, Pbi = 0.2)
+#' Enzyme1.out <- MixNRMI1(x,
+#'   Alpha = 1, Kappa = 0.007, Gama = 0.5,
+#'   distr.k = "gamma", distr.p0 = "gamma",
+#'   asigma = 1, bsigma = 1, Meps = 0.005,
+#'   Nit = 5000, Pbi = 0.2
+#' )
 #' attach(Enzyme1.out)
 #' # Plotting density estimate + 95% credible interval
 #' plot(Enzyme1.out)
@@ -250,8 +252,7 @@ MixNRMI1 <-
           tmp <- gs3_adaptive3(u, n = n, r = r, alpha = Alpha, kappa = Kappa, gama = Gama, delta = delta_U, U = U, iter = j, adapt = adaptive)
           u <- tmp$u_prime
           delta_U <- tmp$delta
-        }
-        else {
+        } else {
           u <- gs3(u,
             n = n, r = r, alpha = Alpha, kappa = Kappa,
             gama = Gama, delta = delta_U
@@ -370,8 +371,7 @@ MixNRMI1 <-
 plot.NRMI1 <- function(x, ...) {
   if (is_censored(x$data)) {
     plotfit_censored(x)
-  }
-  else {
+  } else {
     plotfit_noncensored(x)
   }
 }
