@@ -23,7 +23,7 @@
 #' }
 cens_data_check <-
   function(xleft, xright) {
-    if (any(xright < xleft, na.rm = T)) {
+    if (any(xright < xleft, na.rm = TRUE)) {
       stop("in censored data, left bound not always smaller than right bound")
     }
     if (any(mapply(FUN = function(xileft, xiright) {
