@@ -98,8 +98,7 @@ gsYZstar <-
         q2 <- min(1, f.ratio * k.ratio)
         if (is.na(q2)) {
           flag <- 1
-        }
-        else {
+        } else {
           flag <- 0
           if (runif(1) <= q2) {
             ystar[j] <- y2star
