@@ -2,31 +2,56 @@
 #'
 #' Summarizes the posterior on all possible clusterings by an optimal
 #' clustering where optimality is defined as minimizing the posterior
-#' expectation of a specific loss function, the Variation of Information or
-#' Binder's loss function. Computation can be lengthy for large datasets,
-#' because of the large size of the space of all clusterings.
-#'
+#' expectation of a specific loss function. Supports GreedyEPL and SALSO.
 #'
 #' @param fit The fitted object, obtained from one of the MixNRMIx functions
+#' @param method The method to use for optimal clustering. Can be "GreedyEPL" or "SALSO". Defaults to "GreedyEPL".
 #' @param loss_type Defines the loss function to be used in the expected
-#' posterior loss minimization. Can be one of "VI" (Variation of Information),
-#' "B" (Binder's loss), "NVI" (Normalized Variation of Information) or "NID"
-#' (Normalized Information Distance). Defaults to "VI".
-#' @return A vector of integers with the same size as the data, indicating the
-#' allocation of each data point.
+#' posterior loss minimization. Only used if method is "GreedyEPL". Can be one of "VI", "B", "NVI", or "NID". Defaults to "VI".
+#' @return A vector of integers with the same size as the data, indicating the allocation of each data point.
+#' @examples
+#' \dontrun{
+#' data(acidity)
+#' x <- acidity
+#' # Fitting the model under default specifications
+#' out <- MixNRMI1(x)
+#' compute_optimal_clustering(out)
+#' }
 #' @export compute_optimal_clustering
-compute_optimal_clustering <- function(fit, loss_type = "VI") {
-  if (!requireNamespace("GreedyEPL", quietly = TRUE)) {
-    stop("Package GreedyEPL is needed for this function to work. Please install it.",
-      call. = FALSE
-    )
+compute_optimal_clustering <- function(fit, method = "GreedyEPL", loss_type = "VI") {
+  if (!("Allocs" %in% names(fit))) {
+    stop("The 'fit' object must contain an 'Allocs' element.")
   }
 
-  fit.draw <- Reduce(rbind, fit$Allocs)
-  fit_VI <- GreedyEPL::MinimiseEPL(sample_of_partitions = fit.draw, pars = list("loss_type" = loss_type))
-  return(fit_VI$decision)
+  if (method == "GreedyEPL") {
+    if (!requireNamespace("GreedyEPL", quietly = TRUE)) {
+      stop("Package GreedyEPL is needed for this method. Please install it using install.packages('https://cran.r-project.org/src/contrib/Archive/GreedyEPL/GreedyEPL_1.0.tar.gz', repos = NULL)",
+           call. = FALSE
+      )
+    }
+    fit.draw <- Reduce(rbind, fit$Allocs)
+    fit_VI <- GreedyEPL::MinimiseEPL(sample_of_partitions = fit.draw, pars = list("loss_type" = loss_type))
+    return(fit_VI$decision)
+
+  } else if (method == "SALSO") {
+    if (!requireNamespace("salso", quietly = TRUE)) {
+      stop("Package SALSO is needed for this method. Please install it using install.packages('salso')",
+           call. = FALSE
+      )
+    }
+    alloc_list <- fit$Allocs
+    n <- length(alloc_list[[1]])
+    N_it <- length(alloc_list)
+    mat_clust <- matrix(unlist(alloc_list), nrow = n, ncol = N_it)
+    clust_opt <- salso::salso(x = t(mat_clust), loss = salso::VI())
+    return(clust_opt)
+
+  } else {
+    stop("Invalid method. Choose either 'GreedyEPL' or 'SALSO'.")
+  }
 }
 
+
 # clustering = compute_optimal_clustering(out)
 
 plot_clustering_and_CDF_noncensored <- function(fit, clustering, label_vector = NULL) {
@@ -36,8 +61,7 @@ plot_clustering_and_CDF_noncensored <- function(fit, clustering, label_vector =
 
   if (is_semiparametric(fit)) {
     cdf <- get_CDF_semi_BNPdensity(fit = fit, xs = data)
-  }
-  else {
+  } else {
     cdf <- get_CDF_full_BNPdensity(fit = fit, xs = data)
   }
   p <- ggplot(data.frame(data = data, cluster_id = clustering, cdf = cdf)) +
@@ -58,8 +82,7 @@ plot_clustering_and_CDF_noncensored <- function(fit, clustering, label_vector =
       ),
       aes_string(x = "x", y = "y", colour = "factor(cluster_id)", label = "txt")
     )
-  }
-  else {
+  } else {
     return(p)
   }
 }
@@ -73,8 +96,7 @@ decide_abscissa <- function(censored_data, clustering) {
   df$loc <- unlist(mapply(FUN = function(is_cens, cluster_id, loc) {
     if (is_cens) {
       mean(df$loc[df$cluster_id == cluster_id], na.rm = TRUE)
-    }
-    else {
+    } else {
       loc
     }
   }, df$is_censored, df$cluster_id, df$loc, SIMPLIFY = FALSE))
@@ -91,8 +113,7 @@ plot_clustering_and_CDF_censored <- function(fit, clustering, label_vector = NUL
 
   if (is_semiparametric(fit)) {
     cdf <- get_CDF_semi_BNPdensity(fit = fit, xs = grid[!is.na(grid)])
-  }
-  else {
+  } else {
     cdf <- get_CDF_full_BNPdensity(fit = fit, xs = grid[!is.na(grid)])
   }
   p <- ggplot2::ggplot(
@@ -123,8 +144,7 @@ plot_clustering_and_CDF_censored <- function(fit, clustering, label_vector = NUL
       ),
       aes_string(x = "x", y = "y", colour = "factor(cluster_id)", label = "txt")
     )
-  }
-  else {
+  } else {
     return(p)
   }
 }
@@ -151,8 +171,7 @@ plot_clustering_and_CDF_censored <- function(fit, clustering, label_vector = NUL
 plot_clustering_and_CDF <- function(fit, clustering, label_vector = NULL) {
   if (is_censored(fit$data)) {
     plot_clustering_and_CDF_censored(fit, clustering, label_vector = label_vector)
-  }
-  else {
+  } else {
     plot_clustering_and_CDF_noncensored(fit, clustering, label_vector = label_vector)
   }
 }
